@@ -157,7 +157,7 @@ def add_power_monitor_metaline(monitor_name="", metaline_name=""):
 
 
 def add_basic_monitors_X_prop(x_start=0, x_end=0, distance=0, fdtd_x_min=0, fdtd_x_max=0, fdtd_y_min=0, fdtd_y_max=0,
-							  fdtd_z_min=0, fdtd_z_max=0, mesh_output_flag=False):
+							  fdtd_z_min=0, fdtd_z_max=0, mesh_output_flag=False,mesh_equ_idx=2):
 	'''添加全局监视器，看场俯视图'''
 	FD = get_fdtd_instance()
 	ob_moni_glo = add_global_monitor()
@@ -198,7 +198,12 @@ def add_basic_monitors_X_prop(x_start=0, x_end=0, distance=0, fdtd_x_min=0, fdtd
 	if mesh_output_flag:
 		lupy.simulation.add_mesh(x_min=fdtd_x_max - 0.2 * u, x_max=fdtd_x_max,
 								 y_min=fdtd_y_min, y_max=fdtd_y_max,
-								 z_min=fdtd_z_min, z_max=fdtd_z_max)
+								 z_min=fdtd_z_min, z_max=fdtd_z_max,
+								 set_equ_inx_flag=True,
+								 equ_x_index=mesh_equ_idx,
+								 equ_y_index=mesh_equ_idx,
+								 equ_z_index=mesh_equ_idx,
+								 )
 	return ob_moni_glo, ob_moni_fro, ob_moni_bac, ob_moni_loc, ob_moni_glo1, ob_moni_glo2, ob_moni_loc_outputs
 
 
