@@ -30,7 +30,9 @@ def add_simulation_fdtd(x=0, y=0, z=0, x_min=0, x_max=0, y_min=0, y_max=0, z_min
 	return ob_fdtd
 
 
-def add_mesh(x_min=0, x_max=0, y_min=0, y_max=0, z_min=0, z_max=0):
+def add_mesh(x_min=0, x_max=0, y_min=0, y_max=0, z_min=0, z_max=0,
+			 set_equ_inx_flag=False, equ_x_index=1, equ_y_index=1, equ_z_index=1,
+			 dx=None, dy=None, dz=None):
 	FD = get_fdtd_instance()
 	ob_mesh = FD.addmesh()
 	FD.set("x min", x_min)
@@ -39,6 +41,19 @@ def add_mesh(x_min=0, x_max=0, y_min=0, y_max=0, z_min=0, z_max=0):
 	FD.set("y max", y_max)
 	FD.set("z min", z_min)
 	FD.set("z max", z_max)
+	if set_equ_inx_flag:
+		FD.set("set equivalent index", set_equ_inx_flag)
+		FD.set("equivalent x index", equ_x_index)
+		FD.set("equivalent y index", equ_y_index)
+		FD.set("equivalent z index", equ_z_index)
+	else:
+		# 默认就是设置最大mesh步长，Lumerical会自动给dx,dy,dz（往往很小），所以如果没有手动设置的话就使用原来的
+		if dx:
+			FD.set("dx", dx)
+		if dy:
+			FD.set("dy", dy)
+		if dz:
+			FD.set("dz", dz)
 	return ob_mesh
 
 
